@@ -8,21 +8,14 @@ import jsii
 import publication
 import typing_extensions
 
-import aws_cdk.aws_events._jsii
-import aws_cdk.aws_events_targets._jsii
-import aws_cdk.aws_iam._jsii
-import aws_cdk.aws_lambda._jsii
-import aws_cdk.aws_logs._jsii
-import aws_cdk.aws_route53._jsii
-import aws_cdk.aws_s3._jsii
-import aws_cdk.core._jsii
+import aws_cdk._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "cdk-certbot-dns-route53",
-    "1.0.73",
+    "2.0.6",
     __name__[0:-6],
-    "cdk-certbot-dns-route53@1.0.73.jsii.tgz",
+    "cdk-certbot-dns-route53@2.0.6.jsii.tgz",
 )
 
 __all__ = [
